@@ -1,6 +1,8 @@
 package Slovo::Controller::Stranici;
-
 use Mojo::Base 'Slovo::Controller', -signatures;
+use feature qw(lexical_subs unicode_strings);
+## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
+no warnings "experimental::lexical_subs";
 
 # GET /<:страница>.стр<*пѫт>
 # Display a page in the site
